@@ -22,6 +22,7 @@ Operation recorder interface and implementations.
 """
 
 from __future__ import print_function, absolute_import
+import io
 from collections import namedtuple
 try:
     from collections import OrderedDict
@@ -43,9 +44,6 @@ from ._exceptions import CIMError
 from ._logging import LOGGER_API_CALLS_NAME, LOGGER_HTTP_NAME
 from ._utils import _ensure_unicode, _format
 
-if six.PY2:
-    import codecs  # pylint: disable=wrong-import-order
-
 
 __all__ = ['BaseOperationRecorder', 'TestClientRecorder',
            'LogOperationRecorder',
@@ -241,6 +239,14 @@ class BaseOperationRecorder(object):
         self._conn_id = None
         self.reset()
 
+    def copy(self):
+        """
+        *New in pywbem 1.3.*
+
+        Abstract: Return a deep copy of the object with internal state reset.
+        """
+        raise NotImplementedError  # Must be implemented by subclasses
+
     def enable(self):
         """
         Enable the recorder.
@@ -302,11 +308,8 @@ class BaseOperationRecorder(object):
 
             recorder_file.close()
         """
-        if six.PY2:
-            # Open with codecs to define text mode
-            return codecs.open(filename, mode=file_mode, encoding='utf-8')
-
-        return open(filename, file_mode, encoding='utf8')
+        # pylint: disable=consider-using-with
+        return io.open(filename, file_mode, encoding='utf-8')
 
     def reset(self, pull_op=None):
         """Reset all the attributes in the class. This also allows setting
@@ -511,14 +514,31 @@ class LogOperationRecorder(BaseOperationRecorder):
             self.apilogger = logging.getLogger(LOGGER_API_CALLS_NAME)
             self.httplogger = logging.getLogger(LOGGER_HTTP_NAME)
 
+    def copy(self):
+        """
+        *New in pywbem 1.3.*
+
+        Return a deep copy of the object with internal state reset.
+
+        The user-specifiable attributes of the object are deep-copied, and all
+        other internal state (e.g. staged operations) is reset.
+        """
+        cpy = LogOperationRecorder(
+            conn_id=self._conn_id,
+            detail_levels=self.detail_levels,
+        )  # init makes copies of mutable parameters
+        return cpy
+
     def set_detail_level(self, detail_levels):
         """
         Sets the detail levels from the input dictionary in detail_levels.
+
+        The input dictionary is copied.
         """
         if detail_levels is None:
             return
 
-        self.detail_levels = detail_levels
+        self.detail_levels = dict(detail_levels)  # dict is mutable, so we copy
         if 'api' in detail_levels:
             self.api_detail_level = detail_levels['api']
         if 'http' in detail_levels:
@@ -811,22 +831,39 @@ class TestClientRecorder(BaseOperationRecorder):
             An open file that each test case will be written to.  This file
             should have been opened in text mode.
 
-            Since there are differences between python 2 and 3 in opening
+            Since there are differences between Python 2 and 3 in opening
             files in text mode, the static method
             :meth:`~pywbem.BaseOperationRecorder.open_file`
-            can be used to open the file or python 2/3 compatible open::
+            can be used to open the file.
 
-              from io import open
-                  f = open('blah.log', encoding='utf-8')
+            Alternatively, the Python 2/3 compatible :func:`py:io.open` can be
+            used.
 
-        Example::
+        Examples::
 
           recorder = TestClientRecorder(
               BaseOperationRecorder.open_file('recorder.log'))
+
+          recorder = TestClientRecorder(
+              io.open('recorder.log', mode='w', encoding='utf-8')
         """
         super(TestClientRecorder, self).__init__()
         self._fp = fp
 
+    def copy(self):
+        """
+        *New in pywbem 1.3.*
+
+        Return a copy of the object with internal state reset and reusing the
+        file-like object.
+
+        The attribute for the `fp` init parameter is reused by the returned
+        object without copying it, and any other internal state (e.g. staged
+        operations) is reset.
+        """
+        cpy = TestClientRecorder(fp=self._fp)
+        return cpy
+
     def record(self, pywbem_args, pywbem_result, http_request, http_response):
         """
         Function that records the invocation of a single
