@@ -381,7 +381,7 @@ class WBEMServer(object):
             self._determine_profiles()
         return self._profiles
 
-    def create_namespace(self, namespace):
+    def create_namespace(self, namespace, verbose=False):
         """
         Create the specified CIM namespace in the WBEM server and
         update this WBEMServer object to reflect the new namespace
@@ -420,6 +420,9 @@ class WBEMServer(object):
               The namespace may contain leading and a trailing slash, both of
               which will be ignored.
 
+            verbose (:class:`py:bool`):
+              Verbose mode: Print a message about the namespace creation.
+
         Returns:
 
           :term:`unicode string`: The specified CIM namespace name in its
@@ -433,6 +436,10 @@ class WBEMServer(object):
 
         std_namespace = _ensure_unicode(namespace.strip('/'))
 
+        if verbose:
+            print("Creating namespace {} (in WBEMServer)".
+                  format(std_namespace))
+
         try:
             ws_profiles = self.get_selected_profiles('DMTF', 'WBEM Server')
         except (CIMError, ModelError):
@@ -513,7 +520,8 @@ class WBEMServer(object):
             ns_inst['SystemCreationClassName'] = \
                 self.cimom_inst['SystemCreationClassName']
 
-            self.conn.CreateInstance(ns_inst, namespace=self.interop_ns)
+            interop_ns = self.interop_ns  # Determines the Interop namespace
+            self.conn.CreateInstance(ns_inst, namespace=interop_ns)
 
         # Refresh the list of namespaces in this object to include the one
         # we just created.
@@ -524,7 +532,7 @@ class WBEMServer(object):
 
         return std_namespace
 
-    def delete_namespace(self, namespace):
+    def delete_namespace(self, namespace, verbose=False):
         """
         Delete the specified CIM namespace in the WBEM server and
         update this WBEMServer object to reflect the removed namespace
@@ -562,6 +570,9 @@ class WBEMServer(object):
               The namespace may contain leading and a trailing slash, both of
               which will be ignored.
 
+            verbose (:class:`py:bool`):
+              Verbose mode: Print a message about the namespace creation.
+
         Returns:
 
           :term:`unicode string`: The specified CIM namespace name in its
@@ -578,6 +589,10 @@ class WBEMServer(object):
 
         std_namespace = _ensure_unicode(namespace.strip('/'))
 
+        if verbose:
+            print("Deleting namespace {} (in WBEMServer)".
+                  format(std_namespace))
+
         # Use approach 1: DeleteInstance of CIM class for namespaces
 
         # Refresh the list of namespaces in this object to make sure
@@ -667,7 +682,8 @@ class WBEMServer(object):
               and does not include the required properties.
         """
 
-        org_vm = ValueMapping.for_property(self, self.interop_ns,
+        interop_ns = self.interop_ns  # Determines the Interop namespace
+        org_vm = ValueMapping.for_property(self, interop_ns,
                                            'CIM_RegisteredProfile',
                                            'RegisteredOrganization')
         org_lower = registered_org.lower() \
@@ -686,7 +702,7 @@ class WBEMServer(object):
                     _format("CIM_RegisteredProfile instance in namespace "
                             "{0!A} does not have a property "
                             "'RegisteredOrganization'",
-                            self.interop_ns))
+                            interop_ns))
             inst_org = org_vm.tovalues(inst_org_value)
             try:
                 inst_name = inst['RegisteredName']
@@ -695,7 +711,7 @@ class WBEMServer(object):
                     _format("CIM_RegisteredProfile instance in namespace "
                             "{0!A} does not have a property "
                             "'RegisteredName'",
-                            self.interop_ns))
+                            interop_ns))
             try:
                 inst_version = inst['RegisteredVersion']
             except KeyError:
@@ -703,7 +719,7 @@ class WBEMServer(object):
                     _format("CIM_RegisteredProfile instance in namespace "
                             "{0!A} does not have a property "
                             "'RegisteredVersion'",
-                            self.interop_ns))
+                            interop_ns))
 
             inst_org_lower = inst_org.lower() \
                 if inst_org is not None else None
@@ -1104,8 +1120,8 @@ class WBEMServer(object):
         if interop_ns is None:
             # Exhausted the possible namespaces
             raise ModelError(
-                _format("Interop namespace could not be determined "
-                        "(tried {0!A})", self.INTEROP_NAMESPACES),
+                _format("Interop namespace does not exist (tried {0!A})",
+                        self.INTEROP_NAMESPACES),
                 conn_id=self.conn.conn_id)
         self._interop_ns = interop_ns
 
@@ -1224,8 +1240,9 @@ class WBEMServer(object):
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
             ModelError: An error with the model implemented by the WBEM server.
         """
+        interop_ns = self.interop_ns  # Determines the Interop namespace
         cimom_insts = self._conn.EnumerateInstances(
-            "CIM_ObjectManager", namespace=self.interop_ns)
+            "CIM_ObjectManager", namespace=interop_ns)
         if len(cimom_insts) != 1:
             raise ModelError(
                 _format("Unexpected number of CIM_ObjectManager instances: "
@@ -1299,6 +1316,7 @@ class WBEMServer(object):
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
             ModelError: An error with the model implemented by the WBEM server.
         """
+        interop_ns = self.interop_ns  # Determines the Interop namespace
         mp_insts = self._conn.EnumerateInstances("CIM_RegisteredProfile",
-                                                 namespace=self.interop_ns)
+                                                 namespace=interop_ns)
         self._profiles = mp_insts
