@@ -20,7 +20,7 @@ The :func:`pywbem.siunit_obj` and :func:`pywbem.siunit` functions translate
 the ``PUnit`` and ``Units`` qualifier values into human readable SI conformant
 unit strings.
 
-**Experimental:** *New in 1.1.0 as experimental*
+*New in pywbem 1.1 as experimental and finalized in 1.3.*
 
 Note: These functions do not perform any class operations; they take the
 qualifiers as input.
@@ -108,6 +108,7 @@ import re
 try:
     from collections.abc import Sequence
 except ImportError:
+    # pylint: disable=deprecated-class
     from collections import Sequence
 from nocasedict import NocaseDict
 import six
@@ -124,7 +125,7 @@ def siunit_obj(cim_obj, use_ascii=False):
     Returns a human readable SI conformant unit string from the
     ``PUnit`` or ``Units`` qualifiers of the specified CIM object.
 
-    **Experimental:** *New in 1.1.0 as experimental*
+    *New in pywbem 1.1 as experimental and finalized in 1.3.*
 
     If the CIM object has both the ``PUnit`` and ``Units`` qualifiers set, then
     ``PUnit`` is used and ``Units`` is ignored.
@@ -179,7 +180,7 @@ def siunit(punit=None, units=None, use_ascii=False):
     Returns a human readable SI conformant unit string from the specified
     ``PUnit`` or ``Units`` qualifier values.
 
-    **Experimental:** *New in 1.1.0 as experimental*
+    *New in pywbem 1.1 as experimental and finalized in 1.3.*
 
     If both ``punit`` and ``units`` are specified, then ``punit`` is used and
     ``units`` is ignored.
@@ -743,8 +744,7 @@ def _uc2ascii(uc_str):
     Return the input string, where Unicode characters are replaced with their
     7-bit ASCII replacements as defined in UC2ASCII.
     """
-    for uc in UC2ASCII:
-        ac = UC2ASCII[uc]
+    for uc, ac in UC2ASCII.items():
         uc_str = uc_str.replace(uc, ac)
     return uc_str
 
