@@ -252,7 +252,7 @@ class _MockMOFWBEMConnection(ResolverMixin, BaseRepositoryConnection):
             # The following generates an exception for each new ns
             self.classes[ns][cc.classname] = cc
         except KeyError:
-            self.classes[ns] = NocaseDict({cc.classname: cc})
+            self.classes[ns] = NocaseDict([(cc.classname, cc)])
 
         # Validate that references and embedded instance properties, methods,
         # etc. have classes that exist in repo. This  also institates the
@@ -288,6 +288,9 @@ class _MockMOFWBEMConnection(ResolverMixin, BaseRepositoryConnection):
             elif obj.type == 'string':
                 if 'EmbeddedInstance' in obj.qualifiers:
                     eiqualifier = obj.qualifiers['EmbeddedInstance']
+                    # The DMTF spec allows the value to be None
+                    if eiqualifier.value is None:
+                        continue
                     try:
                         self.GetClass(eiqualifier.value, namespace=ns,
                                       LocalOnly=True,
@@ -309,7 +312,6 @@ class _MockMOFWBEMConnection(ResolverMixin, BaseRepositoryConnection):
                         # Only delete when total failure
                         del self.classes[ns][cc.classname]
                         raise
-
         self.conn.CreateClass(cc, namespace=ns)
 
     def ModifyClass(self, *args, **kwargs):
