@@ -59,6 +59,11 @@ DEFAULT_WBEM_SERVER_MOCK_DICT = {
         'dir': os.path.join(TESTSUITE_SCHEMA_DIR, 'FakeWBEMServer'),
         'files': []},
 
+    # if a url is defined it is set as the url of the mock wbem server
+    'url': None,
+
+    # Leaf classnames that will be installed in the WBEM server from the
+    # dmtf_schema defined above.
     'class_names': ['CIM_Namespace',
                     'CIM_ObjectManager',
                     'CIM_RegisteredProfile',
@@ -73,6 +78,12 @@ DEFAULT_WBEM_SERVER_MOCK_DICT = {
                                       ' Released', },
     'interop_namspace': 'interop',
     'other_namespaces': [],
+    # mock providers that should be installed as part of startup
+    # The common parameter is the namespace for the provider
+    'providers': ["namespace_provider"],
+
+    # Definition of registered profiles.  Each entry creates a registered
+    # profile instance (i.e CIM_RegisteredProfile)
     'registered_profiles': [('DMTF', 'Indications', '1.1.0'),
                             ('DMTF', 'Profile Registration', '1.0.0'),
                             ('SNIA', 'Server', '1.2.0'),
@@ -82,6 +93,7 @@ DEFAULT_WBEM_SERVER_MOCK_DICT = {
                             ('SNIA', 'Software', '1.4.0'),
                             ('DMTF', 'Component', '1.4.0'), ],
 
+    # Each entry creates an instance of
     'referenced_profiles': [
         (('SNIA', 'Server', '1.2.0'), ('DMTF', 'Indications', '1.1.0')),
         (('SNIA', 'Server', '1.2.0'), ('SNIA', 'Array', '1.4.0')),
@@ -129,7 +141,7 @@ class WbemServerMock(object):
     tests
     """
 
-    def __init__(self, interop_ns=None, server_mock_data=None):
+    def __init__(self, interop_ns=None, server_mock_data=None, url=None):
         """
         Build the class repository for with the classes defined for
         the WBEMSERVER.  This is built either from a dictionary of data
@@ -143,6 +155,9 @@ class WbemServerMock(object):
             self.server_mock_data = server_mock_data
 
         self.system_name = self.server_mock_data['system_name']
+        self.url = self.server_mock_data['url']
+        if url:
+            self.url = url
         self.object_manager_name = \
             self.server_mock_data['object_manager']['Name']
 
@@ -180,7 +195,7 @@ class WbemServerMock(object):
              getattr(self, 'wbem_server', None), self.registered_profiles)
         return ret_str
 
-    def build_class_repo(self, default_namespace):
+    def build_class_repo(self, default_namespace, url=None):
         """
         Build the schema qualifier and class objects in the repository
         from a DMTF schema.
@@ -194,7 +209,7 @@ class WbemServerMock(object):
         # pylint: disable=protected-access
 
         FakedWBEMConnection._reset_logging_config()
-        conn = FakedWBEMConnection(default_namespace=default_namespace)
+        conn = FakedWBEMConnection(default_namespace=default_namespace, url=url)
 
         schema = DMTFCIMSchema(self.dmtf_schema_ver, self.schema_dir,
                                verbose=False)
@@ -435,7 +450,7 @@ class WbemServerMock(object):
               the namespaces
               the profiles
         """
-        conn = self.build_class_repo(self.interop_ns)
+        conn = self.build_class_repo(self.interop_ns, self.url)
         server = WBEMServer(conn)
         # NOTE: The wbemserver is not complete until the instances for at
         # least object manager and namespaces have been inserted. Any attempt
@@ -456,9 +471,13 @@ class WbemServerMock(object):
         if self.server_mock_data['other_namespaces']:
             namespaces.extend(self.server_mock_data['other_namespaces'])
 
-        conn.install_namespace_provider(self.interop_ns,
-                                        None,
-                                        verbose=None)
+        # Install providers from prenamed list. Need to add common
+        # method to mocker to replace install_namespace_provider
+        for provider in self.server_mock_data['providers']:
+            if provider == "namespace_provider":
+                conn.install_namespace_provider(self.interop_ns)
+            elif provider == 'subscription_providers':
+                conn.install_subscription_providers(self.interop_ns)
 
         self.build_reg_profile_insts(conn, self.registered_profiles)
 
@@ -472,7 +491,7 @@ class WbemServerMock(object):
         prof_inst = server.get_selected_profiles(registered_org='SNIA',
                                                  registered_name='Server',
                                                  registered_version='1.1.0')
-        # TODO this is simplistic form and only builds one instance
+        # TODO this is simplistic form and only builds one instance of
         # conforms to.  Should expand but need better way to define instance
         # at other end.
         self.build_elementconformstoprofile_inst(conn,
